<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/paquet-jqueryui?lang_cible=pt
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// J
	'jqueryui_description' => 'Este plugin implementa em SPIP a biblioteca complementar jQuery UI, permitindo a criação de componentes gráficos dinâmicos: guias, drag & drop, barras de progresso...
As funcionalidades desta biblioteca dividem-se em três categorias:
-* {{As interacções}}. Podem conferir interessantes propriedades aos elementos HTML, como a capacidade de ser arrastados e movidos com o rato (drag & drop), de ser redimensionados como uma janela, ou de serem seleccionados como ícones no ambiente de trabalho do seu Sistema Operativo.
-* {{Os Widgets}}. São os objectos « chave na mão » que oferecem funções de alto nível como por exemplo DatePicker,  que exibe um calendário para seleccionar uma data.
-* {{Os efeitos}}. Enriquecem os efeitos oferecidos por defeito por jQuery (fadeIn, slideUp...). Graças a jQuery UI, é possível por exemplo animar a propriedade CSS cor de fundo, com .animate() ou adicionar transições para as acções addClass/removeClass...', # MODIF
	'jqueryui_slogan' => 'Animações, efeitos e widgets jQuery'
);

?>
